blockquote_columns.pdf

## Metadata

Title | blockquote_columns.pdf
Path | C:\Users\jenni\OneDrive\Documents\Code\burdoc\burdoc\tests\integration\data\inputs\blockquote_columns.pdf
Pages | 0
PDF Metadata: format | PDF 1.7
PDF Metadata: title |
PDF Metadata: author | Joe Ennis
PDF Metadata: subject |
PDF Metadata: keywords |
PDF Metadata: creator | Microsoft® Word for Microsoft 365
PDF Metadata: producer | Microsoft® Word for Microsoft 365
PDF Metadata: creationDate | D:20230403055232+01'00'
PDF Metadata: modDate | D:20230403055232+01'00'
PDF Metadata: trapped |
PDF Metadata: encryption |

## Contents

1. Page 0

#### Page 0

No images

Path: | content.0.[7,7].bbox
Type: | addition

Key | Old | New
x1 |  | 528.0999755859375
y1 |  | 140.90774536132812
y0 |  | 73.70773315429688
x0 |  | 315.42999267578125

Path: | content.0.[1,1].bbox
Type: | addition

Key | Old | New
x1 |  | 275.4240417480469
y1 |  | 237.74771118164062
y0 |  | 156.74771118164062
x0 |  | 72.02400207519531

Path: | content.0.[8,8].bbox
Type: | addition

Key | Old | New
x1 |  | 519.7979736328125
y1 |  | 247.0592041015625
y0 |  | 157.50924682617188
x0 |  | 315.42999267578125

Path: | content.0.[9,9].bbox
Type: | addition

Key | Old | New
x1 |  | 519.2859497070312
y1 |  | 316.1377258300781
y0 |  | 262.7377014160156
x0 |  | 315.42999267578125

Path: | content.0.[10,10].bbox
Type: | addition

Key | Old | New
x1 |  | 481.3392333984375
y1 |  | 399.171875
y0 |  | 328.0118713378906
x0 |  | 320.5899963378906

Path: | content.0.[11,11].bbox
Type: | addition

Key | Old | New
x1 |  | 526.2100219726562
y1 |  | 467.47772216796875
y0 |  | 414.0777282714844
x0 |  | 315.42999267578125

Path: | content.0.[12,12].bbox
Type: | addition

Key | Old | New
x1 |  | 523.8819580078125
y1 |  | 647.0277099609375
y0 |  | 483.1977233886719
x0 |  | 315.42999267578125

Et quis odio hic neque consequuntur sed similique quia. Ut similique dolorum vel odio provident ut quae sapiente aut quia quia hic quas voluptatem. Ad rerum magni sed consequatur unde et galisum similique.

At quaerat tempora qui nihil quaerat et quos inventore ea delectus perspiciatis. Qui optio labore quo sunt neque et voluptates aspernatur ea consequatur quia et sapiente odit sed nesciunt repudiandae ut cumque nostrum.

Et velit amet ut quos doloremque ut eligendi dolores ex doloremque voluptatem rem cumque totam est internos nostrum.

Est autem optio id voluptatem itaque et maxime nihil ut impedit voluptate ut consequatur vero a laudantium reiciendis. Et officiis vero aut numquam doloremque

Et nobis labore 33 accusamus natus eum itaque sequi vel sapiente internos?

et quisquam exercitationem. Qui consequatur rerum qui molestiae illo aut quisquam rerum et labore totam quo beatae dolores.

Sed impedit consequuntur ea omnis voluptatum non provident culpa et pariatur voluptatibus et tempore rerum qui officia consequatur. Qui accusamus porro est praesentium repudiandae rem ducimus veritatis qui vitae repellendus sed quos voluptatem et natus facilis ex eaque dolore. In beatae ullam est dicta fuga aut veniam illo quo facilis galisum et unde esse. Aut dolores earum ut labore cumque cum sint dicta ut voluptatem quae sed culpa iure!

Et quis odio hic neque consequuntur sed similique quia. Ut similique dolorum vel odio provident ut quae sapiente aut quia quia hic quas voluptatem. Ad rerum magni sed consequatur unde et galisum similique.

Et velit amet ut quos doloremque ut eligendi dolores ex doloremque voluptatem rem cumque totam est internos nostrum.

Est autem optio id voluptatem itaque et maxime nihil ut impedit voluptate ut consequatur vero a laudantium reiciendis. Et officiis vero aut numquam doloremque

Et nobis labore 33 accusamus natus eum itaque sequi vel sapiente internos?

et quisquam exercitationem. Qui consequatur rerum qui molestiae illo aut quisquam rerum et labore totam quo beatae dolores.

Sed impedit consequuntur ea omnis voluptatum non provident culpa et pariatur voluptatibus et tempore rerum qui officia consequatur. Qui accusamus porro est praesentium repudiandae rem ducimus veritatis qui vitae repellendus sed quos voluptatem et natus facilis ex eaque dolore. In beatae ullam est dicta fuga aut veniam illo quo facilis galisum et unde esse. Aut dolores earum ut labore cumque cum sint dicta ut voluptatem quae sed culpa iure!

Et quis odio hic neque consequuntur sed similique quia. Ut similique dolorum vel odio provident ut quae sapiente aut quia quia hic quas voluptatem. Ad rerum magni sed consequatur unde et galisum similique.

At quaerat tempora qui nihil quaerat et quos inventore ea delectus perspiciatis. Qui optio labore quo sunt neque et voluptates aspernatur ea consequatur quia et sapiente odit sed nesciunt repudiandae ut cumque nostrum.

Et velit amet ut quos doloremque ut eligendi dolores ex doloremque voluptatem rem cumque totam est internos nostrum.

Est autem optio id voluptatem itaque et maxime nihil ut impedit voluptate ut consequatur vero a laudantium reiciendis. Et officiis vero aut numquam doloremque

Et nobis labore 33 accusamus natus eum itaque sequi vel sapiente internos?

et quisquam exercitationem. Qui consequatur rerum qui molestiae illo aut quisquam rerum et labore totam quo beatae dolores.

Sed impedit consequuntur ea omnis voluptatum non provident culpa et pariatur voluptatibus et tempore rerum qui officia consequatur. Qui accusamus porro est praesentium repudiandae rem ducimus veritatis qui vitae repellendus sed quos voluptatem et natus facilis ex eaque dolore. In beatae ullam est dicta fuga aut veniam illo quo facilis galisum et unde esse. Aut dolores earum ut labore cumque cum sint dicta ut voluptatem quae sed culpa iure!

Et quis odio hic neque consequuntur sed similique quia. Ut similique dolorum vel odio provident ut quae sapiente aut quia quia hic quas voluptatem. Ad rerum magni sed consequatur unde et galisum similique.

Et velit amet ut quos doloremque ut eligendi dolores ex doloremque voluptatem rem cumque totam est internos nostrum.

Est autem optio id voluptatem itaque et maxime nihil ut impedit voluptate ut consequatur vero a laudantium reiciendis. Et officiis vero aut numquam doloremque

Et nobis labore 33 accusamus natus eum itaque sequi vel sapiente internos?

et quisquam exercitationem. Qui consequatur rerum qui molestiae illo aut quisquam rerum et labore totam quo beatae dolores.

Sed impedit consequuntur ea omnis voluptatum non provident culpa et pariatur voluptatibus et tempore rerum qui officia consequatur. Qui accusamus porro est praesentium repudiandae rem ducimus veritatis qui vitae repellendus sed quos voluptatem et natus facilis ex eaque dolore. In beatae ullam est dicta fuga aut veniam illo quo facilis galisum et unde esse. Aut dolores earum ut labore cumque cum sint dicta ut voluptatem quae sed culpa iure!

Parent File Contents